@@ -90,7 +90,8 @@ class GraphWidget(DOMWidget):
             self,
             widget_layout: Optional[Layout] = None,
             overview_enabled: Optional[bool] = None,
-            context_start_with: Optional[str] = ''
+            context_start_with: Optional[str] = '',
+            graph: Optional = None
     ):
         """GraphWidget constructor.
 
@@ -98,7 +99,7 @@ class GraphWidget(DOMWidget):
         ----------
         widget_layout: ipywidgets.Layout, optional
             Can be used to specify general widget appearance through css attributes.
-            See references for a link to their documentation and available keywords.
+            See ipywidgets documentation for the available keywords.
         overview_enabled: bool, optional
             Enable graph overview component.
             Default behaviour depends on cell width.
@@ -106,6 +107,8 @@ class GraphWidget(DOMWidget):
             Specify context tab name to start with that tab opened.
             Default behaviour is open with About dialog.
             Use None to start with closed sidebar.
+        graph: networkx.{Multi}{Di}Graph | graph_tool.Graph | igraph.Graph | pygraphviz.AGraph, optional
+            Specify the graph to import. Same as calling 'import_graph' after construction
         """
         # the info above should be in class docstring according to official and numpydoc style guide
         # but https://youtrack.jetbrains.com/issue/PY-28900
@@ -115,6 +118,8 @@ class GraphWidget(DOMWidget):
         self._overview = dict(enabled=overview_enabled, overview_set=overview_enabled is not None)
         self._context_pane_mapping = CONTEXT_PANE_MAPPING
         self._sidebar = dict(enabled=context_start_with is not None, start_with=context_start_with)
+        if graph is not None:
+            self.import_graph(graph)
 
     def get_nodes(self):
         """Getter for the nodes traitlets property.
@@ -949,7 +954,7 @@ class GraphWidget(DOMWidget):
         label: str
 
         """
-        properties = element['properties']
+        properties = element.get('properties', {})
         return str(properties.get('label', properties.get('yf_label', index)))
 
     @staticmethod
@@ -995,7 +1000,7 @@ class GraphWidget(DOMWidget):
         properties: typing.Dict
 
         """
-        return element['properties']
+        return element.get('properties', {})
 
     @staticmethod
     def default_node_property_mapping(index: int, node: TDict):
